@@ -136,6 +136,11 @@ guess_frequency <- function(x) {
   UseMethod("guess_frequency")
 }
 
+#' @export
+guess_frequency.numeric <- function(x) {
+  gcd_interval(x)
+}
+
 #' @export
 guess_frequency.yearweek <- function(x) {
   52 / pull_interval(x)$month
@@ -146,11 +151,17 @@ guess_frequency.yearmonth <- function(x) {
   12 / pull_interval(x)$month
 }
 
+#' @export
+guess_frequency.yearmon <- guess_frequency.yearmonth
+
 #' @export
 guess_frequency.yearquarter <- function(x) {
   4 / pull_interval(x)$quarter
 }
 
+#' @export
+guess_frequency.yearqtr <- guess_frequency.yearquarter
+
 #' @export
 guess_frequency.Date <- function(x) {
   7 / pull_interval(x)$day
